---
title: 최소, 최대 결제가 가능한 금액은 얼마인가요?
category: 자주 묻는 질문 (일반 문의) > 결제서비스 > 결제서비스
seo:
  title: 최소, 최대 결제가능금액
  description: >-
    카카오페이, NHN KCP, KG이니시스, 다날, 토스페이먼츠, 페이코, KG모빌리언스, 네이버페이, 나이스페이먼츠, KICC
    한국정보통신, 헥토파이낸셜 등 결제대행사별 최소, 최대 결제가능금액에 대한 가이드입니다.
  keywords:
    - 일반결제
tags:
  - 일반결제
pgCompanies:
  - KG모빌리언스
  - 페이먼트월
  - KICC
  - 헥토파이낸셜
  - 네이버페이(결제형)
  - 페이코
  - 토스페이먼츠
  - 나이스페이먼츠
  - 다날
  - NHN KCP
  - 카카오페이
  - KG이니시스
searchTags:
  - 결제한도
  - 한도
  - 최대금액
  - 최소금액
  - 최대결제금액
  - 최소결제금액
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="결제대행사별로 기본적으로 설정되는 최소/최대 결제 가능금액을 안내드리며, 
심사 결과에 따라 금액은 상이해질 수 있는 점 참고해주시기 바랍니다." />

#### **카카오페이**

- **실제 운영 환경**
  - 신용카드
    - 최소 : 100원
    - 최대 : 200만원 미만
  - 카카오머니
    - 최소 : 100원
    - 최대 : 1회 결제한도 200만원 (1회 충전한도는 200만원, 제한 한도 금액은 없음)
- **테스트 운영 환경**
  - 신용카드
    - 최소 : 설정되어 있지 않음
    - 최대 : 100만원 미만
  - 카카오머니
    - 최소 : 설정되어 있지 않음
    - 최대 : 100만원

#### **NHN KCP**

- **실제 운영 환경**
  - 신용카드 : 최소 1000원(별도 요청 시 100원까지 설정 가능합니다)
  - 실시간 계좌이체 : 최소 400원
  - 가상계좌 : 최소 301원
  - 휴대폰 소액 결제 : 최소 400원
  - 수기 및 간편결제도 동일하며, 카카오 머니와 SSG 머니는 최소 100원 이상
- **테스트 운영 환경**
  - 신용카드 : 최소 100원
  - 실시간 계좌 이체 : 최소 100원
  - 가상계좌 : 최소 1원
  - 휴대폰 소액결제 : 최소 1원

#### **KG이니시스**

- **실제 운영 환경**
  - 신용카드 : 최소 100원 / 삼성카드 100원 , 그 외 카드 10원
    (다만, 최소결제 금액은 van사와 카드사 정책에 따라 변경될 수 있습니다)
  - 실시간 계좌이체 : 최소 150원 (우리은행의 경우, 151원부터 결제 가능)
  - 휴대폰 소액결제 : 최소 300원 (300원 미만 결제를 원할 경우, 원천사 별도 협의 필요)
- **테스트 운영 환경**
  - 휴대폰 결제 : 최소 1원 (테스트 MID라 별도 협의됨)

#### **다날**

- **실제 운영 환경**
  - 신용카드 : 최소 100원
  - 실시간 계좌이체 : 최소 301원
  - 가상계좌 : 최소 301원
  - 휴대폰 소액결제 : 최소 301원

#### **토스페이먼츠**

- **실제 운영 환경**
  - 신용카드 : 최소 100원
  - 실시간 계좌이체 : 최소 200원
  - 가상계좌 : 최소 1원
  - 휴대폰 소액결제 : 최소 300원

#### **페이코**

- **실제 운영 환경**
  - 신용카드 : 최소 100원 (30만원 이상 결제 시 ARS 인증\_공인인증서 불필요)
  - 간편계좌 : 최소 100원 (일 200만원 / 월 500만원 한도)
  - 가상계좌 : 최소 100원
  - 쿠폰 : 없음 (사용 가능한 결제 수단은 쿠폰별 상이)
  - 포인트: 1원 ( ID 당 최대 200만 포인트까지만 보유 가능)

#### **KG모빌리언스**

- **실제 운영 환경**
  - 휴대폰 소액결제 : 최소 301원

#### **네이버페이**

- **실제 운영 환경**
  - 신용카드 : 최소 10원
  - 간편계좌 : 최소 10원
  - 포인트 : 최소 10원

#### **나이스페이먼츠**

- **실제 운영 환경**
  - 신용카드 : 최소 100원
  - 실시간 계좌이체 : 최소 200원
  - 가상계좌 : 최소 1원
  - 휴대폰 소액결제 : 최소 500원

#### **페이먼트월**

- **실제 운영 환경**
  - 결제수단별로 각각 상이하며 아래 가이드에서 상세 확인 가능(Min Transaction Limit)
  - [페이먼트월 결제수단별 상세 기준 보러가기↗](https://docs.paymentwall.com/payment-method/credit-card)

#### **이지페이(KICC)**

- **실제 운영 환경**
  - 신용카드 : 최소 100원

#### **헥토파이낸셜**

- **실제 운영 환경**
  - 신용카드 : 최대한도는 계약 시 심사 후 결정 (보통 1회 최대 승인한도 1\~2천만원)\
    (심사결과에 따라 달라질 수 있음)
  - 실시간 계좌이체 : 최대 2백만원
  - 가상계좌 : 최대 1백만원
  - 내통장결제 : 최대 200만원(일 당) 500만원(월 당)

#### 웰컴페이먼츠

- **실제 운영 환경**
  - 신용카드 (일반, 수기, 빌링 동일)
    - 최소 : 1,000원이하로 설정가능
    - 최대 : 999,999,999원 (단, RM과 협의 필요)
  - 간편결제
    - 신용카드와 동일
  - 계좌이체
    - 최소 : 300원 이상
  - 가상계좌
    - 최소 : 300원 이상
  - 휴대폰
    - 최소 : 없음
    - 최대 : 200만원
